@@ -2,8 +2,8 @@ from abc import ABCMeta, abstractmethod
 from dataclasses import dataclass
 import pandas as pd
 
-from kedab.kedab.activation import Activation
-from kedab.kedab.enum_regularization import Regularization
+from .activation import Activation
+from .enum_regularization import Regularization
 
 
 @dataclass
